@@ -26,6 +26,8 @@ use std::thread::JoinHandle;
 use crate::anyhow::anyhow;
 use futures::channel::{mpsc, mpsc::Sender, oneshot};
 use futures_util::{SinkExt, StreamExt};
+use png::{PixelDimensions, Unit};
+use tiny_skia::{Pixmap, PremultipliedColorU8};
 use usvg::{TreeParsing, TreeTextToPath};
 
 use crate::text::{op_text_width, FONT_DB, USVG_OPTIONS};
@@ -688,10 +690,11 @@ impl VlConverter {
         &mut self,
         vg_spec: serde_json::Value,
         scale: Option<f32>,
+        ppi: Option<f32>,
     ) -> Result<Vec<u8>, AnyError> {
         let scale = scale.unwrap_or(1.0);
         let svg = self.vega_to_svg(vg_spec).await?;
-        Self::svg_to_png(&svg, scale)
+        Self::svg_to_png(&svg, scale, ppi)
     }
 
     pub async fn vegalite_to_png(
@@ -699,13 +702,17 @@ impl VlConverter {
         vl_spec: serde_json::Value,
         vl_opts: VlOpts,
         scale: Option<f32>,
+        ppi: Option<f32>,
     ) -> Result<Vec<u8>, AnyError> {
         let scale = scale.unwrap_or(1.0);
         let svg = self.vegalite_to_svg(vl_spec, vl_opts).await?;
-        Self::svg_to_png(&svg, scale)
+        Self::svg_to_png(&svg, scale, ppi)
     }
 
-    fn svg_to_png(svg: &str, scale: f32) -> Result<Vec<u8>, AnyError> {
+    fn svg_to_png(svg: &str, scale: f32, ppi: Option<f32>) -> Result<Vec<u8>, AnyError> {
+        // default ppi to 72
+        let ppi = ppi.unwrap_or(72.0);
+        let scale = scale * ppi / 72.0;
         let opts = USVG_OPTIONS
             .lock()
             .map_err(|err| anyhow!("Failed to acquire usvg options lock: {}", err.to_string()))?;
@@ -736,7 +743,7 @@ impl VlConverter {
             let transform = tiny_skia::Transform::from_scale(scale, scale);
             resvg::Tree::render(&rtree, transform, &mut pixmap.as_mut());
 
-            Ok(pixmap.encode_png())
+            Ok(encode_png(pixmap, ppi))
         });
         match response {
             Ok(Ok(Ok(png_result))) => Ok(png_result),
@@ -796,6 +803,39 @@ impl Default for VlConverter {
     }
 }
 
+// Modified from tiny-skia-0.10.0/src/pixmap.rs to include DPI
+pub fn encode_png(pixmap: Pixmap, ppi: f32) -> Result<Vec<u8>, AnyError> {
+    let mut pixmap = pixmap;
+
+    // Demultiply alpha.
+    //
+    // RasterPipeline is 15% faster here, but produces slightly different results
+    // due to rounding. So we stick with this method for now.
+    for pixel in pixmap.pixels_mut() {
+        let c = pixel.demultiply();
+        *pixel = PremultipliedColorU8::from_rgba(c.red(), c.green(), c.blue(), c.alpha())
+            .expect("from_rgba returned None");
+    }
+
+    let mut data = Vec::new();
+    {
+        let mut encoder = png::Encoder::new(&mut data, pixmap.width(), pixmap.height());
+        encoder.set_color(png::ColorType::Rgba);
+        encoder.set_depth(png::BitDepth::Eight);
+        let ppm = (ppi.max(0.0) / 0.0254).round() as u32;
+        encoder.set_pixel_dims(Some(PixelDimensions {
+            xppu: ppm,
+            yppu: ppm,
+            unit: Unit::Meter,
+        }));
+
+        let mut writer = encoder.write_header()?;
+        writer.write_image_data(pixmap.data())?;
+    }
+
+    Ok(data)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
